==> ruby-qt-0.13.tgz: lib/ruby/site_ruby/1.6/qt.rb <==
require "qt.so"
include Qt
#Qt module functions - ruby part

module Qt
#Translate Qt signal and slot to argument of connect function
def QSIGNAL(str)
	"2" + str
end

def QSLOT(str)
	"1" + str
end

def QMAX(a,b)
  if(a > b)
    return a 
  else
    return b 
  end
end

def QMIN(a,b)
  if(a > b)
    return b
  else
    return a
  end
end

#Modifier of installEventFilter function
class QObject
def catchEvent
   @eventfilter = QREventFilter.new(self)
   self.installEventFilter(@eventfilter)
end
end

#Modify initializaion of QObject. Is it convenient?
#class QObject
#def initialize w=nil, name="", wf=0 , a0=nil, a1=nil, a2=nil, a3=nil, a4=nil, a5=nil, a6=nil, a7=nil, a8=nil, a9=nil, a10=nil, a11=nil, a12=nil, a13=nil, a14=nil
#   catchEvent
#end
#end


#Modifier connect function
def connect(arg1, arg2, arg3=nil, arg4=nil)
   if ( arg1.is_a?(RSignal))
      if (arg2.is_a?(RSignal))
         r = RObject::connect_rsignalrsignal(arg1,arg2)
         return r
      elsif ((arg2.is_a?(QObject)) and (arg3.is_a?(String)))
         if((arg3[0].chr == "1") or (arg3[0].chr == "2")) #Qt Signal or Slot
            r = QRObject::connect_rsignal(arg1,arg2,arg3)
            return r
         elsif (arg2.respond_to?(arg3))
            r = QRObject::connect_rsignalslot(arg1,arg2,arg3)
            return r
         else
            raise "3rd argument error in connect(#{arg3})"
            return
         end
      else
         raise "2nd argument error in connect(#{arg2})"
         return
      end
   elsif (((arg1.is_a?(QObject)) or (arg1.is_a?(QMenuBar)))and (arg2.is_a?(String)))
      if (arg2[0].chr == "2") #Qt Signal
         if ((arg3.is_a?(QObject)) and (arg4.is_a?(String)))
            if((arg4[0].chr == "1") or (arg4[0].chr == "2")) #Qt Signal or Slot
               QObject::connect(arg1,arg2,arg3,arg4)
               return
            elsif (not (arg4.is_a?(String)))
               raise "4th argument is not a String in connect(#{arg4})"
               return
            elsif (arg3.respond_to?(arg4))
               r = QRObject::connect_rslot(arg1,arg2,arg3,arg4)
               return r
            else
               raise "4th argument is not a String in connect(#{arg4})"
               return
            end
         elsif (arg3.is_a?(RSignal))
            r = QRObject::connect_qsignalrsignal(arg1,arg2,arg3)
            return r
         else
            raise "3th argument error in connect(#{arg3})"
            return
         end
      else
         raise "2nd argument error in connect(#{arg2})"
         return
      end
   else
      raise "1st argument error in connect(#{arg1})"
      return
   end
end

#Modifier of connectItem function.
#Override connectItem  in QAccel class
class QAccel
alias qt_connectItem connectItem
def connectItem( id , receiver, method = nil)
   if (not (id.is_a?(Fixnum)))
      raise "1st argument is not a FIXNUM in connectItem"
      return
   elsif (receiver.is_a?(RSignal))
      return QRObject::connectItem_rsignal(self,id,receiver,method)
   elsif (not (receiver.is_a?(QObject)))
      raise "2nd argument is not a QObject in connectItem"
      return
   elsif (not (method.is_a?(String)))
      raise "3rd argument is not a String in connectItem"
      return
   elsif ((method[0].chr == "1") or (method[0].chr == "2")) # Qt signal or slot
      return self.qt_connectItem(id,receiver,method)
   else
      return QRObject::connectItem_rslot(self,id,receiver,method)
   end
return false
end
end


#For Color Definition
# Use X11 rgb.txt in /usr/X11R6/lib/X11 dir and
# return QColor object
# It is replacement of QColor(const char*) constructor.

ColorDic = Hash.new([0,0,0])
def QColor cname
   dat = findColor cname
   return QColor.new(dat[0],dat[1],dat[2])
end

#Find color named s from ColorDic or rgb.txt in X11 lib
#
# Use ColorDic = Hash.new([0,0,0])

def findColor s
   if (ColorDic.has_key?(s))
      return ColorDic[s]
   end
   if (not (File::exist?("/usr/X11R6/lib/X11/rgb.txt")))
      print "There is no rgb.txt in /usr/X11R6/lib/X11 dir.\n"
      return [0,0,0]
   else
      rgb = File::open("/usr/X11R6/lib/X11/rgb.txt","r")
      rgb.each do |line|
          dat = line.split
          if(dat[0][0] == "!")
             #skip
          else
             data3 = dat[0..2]
             data3.collect!{|i| i.to_i}
             if (dat.size == 4)
                name = dat[3]
             else
                datname = dat[3..(dat.size - 1)]
                name = datname.join(" ")
             end
             ColorDic.store(name, data3)
          end
      end
      rgb.close
   end
   return ColorDic[s]
end

#For translate QString to String.
# This is move to qt.qarray.i and translated to qt_wrap.cc 000315 by horie
#class QString
#def to_str
#   qstr2str(self)
#end

#For delete function for QObject
def delete obj
    deleteQObj( obj )
    nil
end

end
#For initialization of QRObject
QRObject::QRObj_init()

==> ruby-qt-0.15.tgz: lib/ruby/site_ruby/1.6/qt.rb <==
require "qt.so"
include Qt
#Qt module functions - ruby part

module Qt
#Translate Qt signal and slot to argument of connect function
def QSIGNAL(str)
	"2" + str
end

def QSLOT(str)
	"1" + str
end

def QMAX(a,b)
  if(a > b)
    return a 
  else
    return b 
  end
end

def QMIN(a,b)
  if(a > b)
    return b
  else
    return a
  end
end

#Modifier of installEventFilter function
class QObject
def catchEvent
   @eventfilter = QREventFilter.new(self)
   self.installEventFilter(@eventfilter)
end
end

#Modify initializaion of QObject. Is it convenient?
#class QObject
#def initialize w=nil, name="", wf=0 , a0=nil, a1=nil, a2=nil, a3=nil, a4=nil, a5=nil, a6=nil, a7=nil, a8=nil, a9=nil, a10=nil, a11=nil, a12=nil, a13=nil, a14=nil
#   catchEvent
#end
#end


#Modifier connect function
def connect(arg1, arg2, arg3=nil, arg4=nil)
   if ( arg1.is_a?(RSignal))
      if (arg2.is_a?(RSignal))
         r = RObject::connect_rsignalrsignal(arg1,arg2)
         return r
      elsif ((arg2.is_a?(QObject)) and (arg3.is_a?(String)))
         if((arg3[0].chr == "1") or (arg3[0].chr == "2")) #Qt Signal or Slot
            r = QRObject::connect_rsignal(arg1,arg2,arg3)
            return r
         elsif (arg2.respond_to?(arg3))
            r = QRObject::connect_rsignalslot(arg1,arg2,arg3)
            return r
         else
            raise "3rd argument error in connect(#{arg3})"
            return
         end
      else
         raise "2nd argument error in connect(#{arg2})"
         return
      end
   elsif (((arg1.is_a?(QObject)) or (arg1.is_a?(QMenuBar)))and (arg2.is_a?(String)))
      if (arg2[0].chr == "2") #Qt Signal
         if ((arg3.is_a?(QObject)) and (arg4.is_a?(String)))
            if((arg4[0].chr == "1") or (arg4[0].chr == "2")) #Qt Signal or Slot
               QObject::connect(arg1,arg2,arg3,arg4)
               return
            elsif (not (arg4.is_a?(String)))
               raise "4th argument is not a String in connect(#{arg4})"
               return
            elsif (arg3.respond_to?(arg4))
               r = QRObject::connect_rslot(arg1,arg2,arg3,arg4)
               return r
            else
               raise "4th argument is not a String in connect(#{arg4})"
               return
            end
         elsif (arg3.is_a?(RSignal))
            r = QRObject::connect_qsignalrsignal(arg1,arg2,arg3)
            return r
         else
            raise "3th argument error in connect(#{arg3})"
            return
         end
      else
         raise "2nd argument error in connect(#{arg2})"
         return
      end
   else
      raise "1st argument error in connect(#{arg1})"
      return
   end
end

#Modifier of connectItem function.
#Override connectItem  in QAccel class
class QAccel
alias qt_connectItem connectItem
def connectItem( id , receiver, method = nil)
   if (not (id.is_a?(Fixnum)))
      raise "1st argument is not a FIXNUM in connectItem"
      return
   elsif (receiver.is_a?(RSignal))
      return QRObject::connectItem_rsignal(self,id,receiver,method)
   elsif (not (receiver.is_a?(QObject)))
      raise "2nd argument is not a QObject in connectItem"
      return
   elsif (not (method.is_a?(String)))
      raise "3rd argument is not a String in connectItem"
      return
   elsif ((method[0].chr == "1") or (method[0].chr == "2")) # Qt signal or slot
      return self.qt_connectItem(id,receiver,method)
   else
      return QRObject::connectItem_rslot(self,id,receiver,method)
   end
return false
end
end


#For Color Definition
# Use X11 rgb.txt in /usr/X11R6/lib/X11 dir and
# return QColor object
# It is replacement of QColor(const char*) constructor.

ColorDic = Hash.new([0,0,0])
def QColor cname
   dat = findColor cname
   return QColor.new(dat[0],dat[1],dat[2])
end

#Find color named s from ColorDic or rgb.txt in X11 lib
#
# Use ColorDic = Hash.new([0,0,0])

def findColor s
   rgbfile = nil
   if (ColorDic.has_key?(s))
      return ColorDic[s]
   end
   if (File::exist?("/usr/X11R6/lib/X11/rgb.txt"))
      rgbfile = "/usr/X11R6/lib/X11/rgb.txt"
   elsif (File::exist?("/usr/openwin/lib/rgb.txt"))
      rgbfile = "/usr/openwin/lib/rgb.txt"
   else 
      print "There is no rgb.txt in /usr/X11R6/lib/X11 dir.\n"
      return [0,0,0]
   end 
   rgb = File::open(rgbfile,"r")
   rgb.each do |line|
       dat = line.split
       if(dat[0][0] == "!")
          #skip
       else
          data3 = dat[0..2]
          data3.collect!{|i| i.to_i}
          if (dat.size == 4)
             name = dat[3]
          else
             datname = dat[3..(dat.size - 1)]
             name = datname.join(" ")
          end
          ColorDic.store(name, data3)
       end
   end
   rgb.close
   return ColorDic[s]
end

#For translate QString to String.
# This is move to qt.qarray.i and translated to qt_wrap.cc 000315 by horie
#class QString
#def to_str
#   qstr2str(self)
#end

#For delete function for QObject
def delete obj
    deleteQObj( obj )
    nil
end

end
#For initialization of QRObject
QRObject::QRObj_init()
